==> haskell-th-utilities-0.2.5.0-48-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-th-utilities.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 th-utilities
version:              0.2.5.0
visibility:           public
id:                   th-utilities-0.2.5.0-ATaxcpGX42l50lxTZDul2T
key:                  th-utilities-0.2.5.0-ATaxcpGX42l50lxTZDul2T
license:              MIT
copyright:            2016 FP Complete
maintainer:           Michael Sloan <mgsloan@gmail.com>
homepage:             https://github.com/fpco/th-utilities#readme
synopsis:
    Collection of useful functions for use with Template Haskell

category:             Template Haskell
abi:                  6343918f8cc0c413481ee153e9ce6f17
exposed:              True
exposed-modules:
    TH.Derive TH.Derive.Storable TH.FixQ TH.ReifySimple
    TH.RelativePaths TH.Utilities

hidden-modules:       TH.Derive.Internal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/th-utilities-0.2.5.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/th-utilities-0.2.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-utilities
hs-libraries:         HSth-utilities-0.2.5.0-ATaxcpGX42l50lxTZDul2T
depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    directory-1.3.6.2 filepath-1.4.2.2
    primitive-0.7.4.0-A9DQl7IN10ADdryf8HN1sF
    syb-0.7.2.4-3l4i7x4UWHaFMYIEmP3T6l template-haskell-2.18.0.0
    text-1.2.5.0 th-abstraction-0.4.5.0-FQrzhXbdvQX3Z0wTw3euNu
    th-orphans-0.13.14-IFdr808Ei4NTG64FhXomg

haddock-interfaces:
    /usr/share/doc/haskell-th-utilities/html/th-utilities.haddock

haddock-html:         /usr/share/doc/haskell-th-utilities/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-utilities-0.2.5.0-50-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-th-utilities.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 th-utilities
version:              0.2.5.0
visibility:           public
id:                   th-utilities-0.2.5.0-84jzAXFraUCG2d0K9acHve
key:                  th-utilities-0.2.5.0-84jzAXFraUCG2d0K9acHve
license:              MIT
copyright:            2016 FP Complete
maintainer:           Michael Sloan <mgsloan@gmail.com>
homepage:             https://github.com/fpco/th-utilities#readme
synopsis:
    Collection of useful functions for use with Template Haskell

category:             Template Haskell
abi:                  abe6b4b319d5605c94c5241dd8c1e033
exposed:              True
exposed-modules:
    TH.Derive TH.Derive.Storable TH.FixQ TH.ReifySimple
    TH.RelativePaths TH.Utilities

hidden-modules:       TH.Derive.Internal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/th-utilities-0.2.5.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/th-utilities-0.2.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-utilities
hs-libraries:         HSth-utilities-0.2.5.0-84jzAXFraUCG2d0K9acHve
depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    directory-1.3.6.2 filepath-1.4.2.2
    primitive-0.7.4.0-AQ7cOoBXu5aBgAQTQzTLUx
    syb-0.7.2.4-4iiIjHgm67gJA1HTgFmr8s template-haskell-2.18.0.0
    text-1.2.5.0 th-abstraction-0.4.5.0-FQrzhXbdvQX3Z0wTw3euNu
    th-orphans-0.13.14-9IVv0eQKqVy5rA0nZ47ezc

haddock-interfaces:
    /usr/share/doc/haskell-th-utilities/html/th-utilities.haddock

haddock-html:         /usr/share/doc/haskell-th-utilities/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
